ggml : allow fill node alloc inplace (#17870)

This commit is contained in:
Sigbjørn Skjæret
2025-12-09 12:23:47 +01:00
committed by GitHub
parent 63908b631a
commit 86a3f0fad8
2 changed files with 2 additions and 1 deletions
+1 -1
View File
@@ -4,7 +4,7 @@
#define CUDA_FILL_BLOCK_SIZE 256
template <typename T>
static __global__ void fill_kernel(T * __restrict__ dst, const int64_t k, const T value) {
static __global__ void fill_kernel(T * dst, const int64_t k, const T value) {
const int64_t i = (int64_t)blockDim.x * blockIdx.x + threadIdx.x;
if (i >= k) {
return;